@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.127 2008/02/14 08:44:16 bowkenken Exp $
+* $Id: fight.c,v 1.128 2008/04/06 08:00:03 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -879,16 +879,19 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 	arw.next = NULL;
 	if( attack->flg_throw && (o_k == CHR_KIND_MBR) ){
 		eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
-		if( eq[EQUIP_KIND_ARW].kind == ITEM_KIND_NULL ){
-			print_msg( FLG_MSG_ERR, MSG_ERR_THROW, o_name );
+		if( eq != NULL ){
+			if( eq[EQUIP_KIND_ARW].kind == ITEM_KIND_NULL ){
+				print_msg( FLG_MSG_ERR, MSG_ERR_THROW,
+						o_name );
 
-			clr_chr_trgt_act( (mbr_t *)o_p, TRUE );
+				clr_chr_trgt_act( (mbr_t *)o_p, TRUE );
 
-			return FALSE;
+				return FALSE;
+			}
+
+			copy_item( &arw, &(eq[EQUIP_KIND_ARW]) );
+			arw.n = 1;
 		}
-
-		copy_item( &arw, &(eq[EQUIP_KIND_ARW]) );
-		arw.n = 1;
 	}
 
 	/* ΥΥå */
