@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.99 2007/12/24 16:36:55 bowkenken Exp $
+* $Id: gmain.c,v 1.101 2008/01/31 20:24:31 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -73,7 +73,7 @@ static struct termio	pre_tbuf;
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUT:D:S:l:k:e:s:p:md:Vh"
+#define	STR_OPT	"GCUT:D:S:l:k:e:s:p:md:Vvh"
 
 #if	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
@@ -127,7 +127,7 @@ char	str_usage[] = {
 	"  -d, --debug=FLAG         set debug mode:\n"
 	"                             ON or OFF\n"
 #endif
-	"  -V, --version            display version and exit\n"
+	"  -V, -v, --version        display version and exit\n"
 	"  -h, --help               display this help and exit\n"
 };
 
@@ -273,6 +273,7 @@ void	chk_arg( int argc, char **argv )
 			chk_opt_flg( optarg, &g_flg_debug, TRUE );
 			break;
 		case 'V':
+		case 'v':
 			version( stdout );
 			gexit( EXIT_SUCCESS );
 			break;
@@ -417,9 +418,6 @@ void	overwrite_arg()
 
 void	usage( FILE *fp )
 {
-	if( !g_flg_cui )
-		return;
-
 	fprintf( fp, str_usage, STR_FILE_NAME_GAME );
 	fflush( fp );
 }
