@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.40 2008/04/03 08:17:01 bowkenken Exp $
+* $Id: imenu.c,v 1.41 2008/04/06 08:00:04 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -795,7 +795,11 @@ void	exec_menu_edit_mbr_data(
 	case DATA_N_ITEM_14:
 	case DATA_N_ITEM_15:
 		item_n = n - DATA_N_ITEM_00;
+
 		item_head = get_mbr_item_asgn( mbr );
+		if( item_head == NULL )
+			break;
+
 		item = item_head->next;
 		for( i = 0; i < item_n; i++, item = item->next )
 			if( item == item_head )
@@ -819,6 +823,9 @@ void	exec_menu_edit_mbr_data(
 	case DATA_N_EQUIP_FEET:
 	case DATA_N_EQUIP_LIGHT_SOURCE:
 		item = get_mbr_item_asgn_equip( mbr );
+		if( item == NULL )
+			break;
+
 		eq_k = (equip_kind_t)(EQUIP_KIND_NULL
 				+ (n - DATA_N_EQUIP_WIELDING));
 
