@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.h,v 1.39 2007/06/07 22:58:14 bowkenken Exp $
+* $Id: menu.h,v 1.45 2008/01/11 09:12:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_H
@@ -37,12 +37,14 @@
 #include	"party.h"
 #include	"msg.h"
 
-/*  */
+/***************************************************************/
+
+/****  ****/
 
 #define	STR_MENU_ERR	"# Error"
 #define	STR_MENU_CANCEL	".."
 
-/* ˥塼ѤΥ */
+/**** ˥塼ѤΥ ****/
 
 #define	CASE_ENTER	\
 		'M' - '@': case 'J' - '@'
@@ -113,31 +115,70 @@
 #define	MENU_SHORT_KEY_MAX_LEN	16
 
 /* ܤκʸ */
-#define	MENU_MSG_MAX_LEN	70
+#define	MENU_MSG_MAX_LEN	(80 * 6 / 2)
 
-/* ֡ */
+/**** ֡ ****/
 
 #define	MENU_SAVE_LOAD_MAX_N	40
 #define	MENU_SAVE_LOAD_N_PER_PAGE	10
 
+/**** 饯 ****/
+
+/* 饯ȤΥڡ򥫡롦Ǥ᤯뤫? */
+/* TRUE ξ硢롦ǥڡ˥塼ǥС᤯ */
+/* FALSE ξ硢롦ǥС˥塼ǥڡ᤯ */
+#define	MBR_DATA_CHANGE_PAGE_IS_CRSR	TRUE
+
 /* 饯Ȥκڡ */
 #define	MBR_DATA_PAGE_MAX_N	4
 
+/**** 桼˥塼 ****/
+
 /* 桼˥塼κܿ */
 #define	USER_MENU_MAX_N	(MENU_MAX_N_PER_PAGE * 4)
 
-/* ˥塼Υ롦Хåؿ */
+/**** ޥɡ˥塼 ****/
+
+#define	MENU_COMMAND_KEY_CHAR	':'
+#define	MENU_COMMAND_KEY_STR	":"
+#define	MENU_COMMAND_MAX_LEN	2048
+
+/**** ˥塼Υ롦Хåؿ ****/
 
 struct menu_t;
 typedef char	*(*menu_call_back_t)(
 	struct menu_t **pp, struct menu_t **dflt );
 
-/* ޥåפΥ */
+/**** ޥåפΥ ****/
 
 typedef unsigned long	flg_scroll_t;
 #define	FLG_SCROLL_SMOOTH	(1 << 0)
 #define	FLG_SCROLL_CENTER	(1 << 1)
 
+/**** ե󥯥󡦥 ****/
+
+/* ե󥯥󡦥κ */
+#define	FUNC_KEY_MAX	50
+
+/**** ޥ⡼бե󥯥󡦥 ****/
+
+typedef enum {
+	FUNC_N_CLICK_L = 21,
+	FUNC_N_CLICK_M,
+	FUNC_N_CLICK_R,
+	FUNC_N_CLICK_0 = FUNC_N_CLICK_L,
+
+	FUNC_N_PRESS_L_CLICK_R = 31,
+	FUNC_N_PRESS_R_CLICK_L,
+
+	FUNC_N_MOTION_LEFT = 41,
+	FUNC_N_MOTION_RIGHT,
+	FUNC_N_MOTION_UP,
+	FUNC_N_MOTION_DOWN,
+} func_n_t;
+
+/***************************************************************/
+
 /* ˥塼 */
 
 typedef struct menu_t {
@@ -211,6 +252,14 @@ typedef enum {
 	MENU_NUM_MAX_N
 } menu_num_t;
 
+/* ϥ */
+
+#define	KEY_MENU_NUM_OK	'Z'
+#define	KEY_MENU_NUM_CLR	'Y'
+#define	KEY_MENU_NUM_MAX	'X'
+#define	KEY_MENU_NUM_MIN	'W'
+#define	KEY_MENU_NUM_SGN	'V'
+
 /* ֥ */
 
 typedef enum {
