@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.24 2007/11/02 18:23:49 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.26 2008/04/03 08:17:01 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -748,6 +748,33 @@ menu_t	ls_menu_main[] = {
 		cb_menu_mul_msg_line, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/screen/window/size",
+		"<Branch>",
+		'Z',
+		"",
+		N_MSG_MENU_SCREEN_SIZE, "",
+		cb_menu_screen_size_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window/size/auto",
+		"<CheckItem>",
+		'A',
+		"",
+		N_MSG_MENU_SCREEN_SIZE_AUTO, "",
+		cb_menu_screen_size_auto, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window/size/lines",
+		"<OpenWinItem>",
+		'L',
+		"",
+		N_MSG_MENU_SCREEN_SIZE_LINES, "",
+		cb_menu_screen_size_lines, NULL,
+		FLG_NULL,
+	},
 /* VFX begin */
 	{
 		"/misc/config/screen/vfx",
