@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.32 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: mmenu.c,v 1.33 2008/04/06 08:00:04 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -1341,23 +1341,25 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 		k++;
 
 		item = get_mbr_item_asgn( pty->mbr[i] );
-		p = item->next;
-		for( j = 0; j < MBR_ITEM_MAX_N; j++, p = p->next ){
-			if( p == item )
-				break;
+		if( item != NULL ){
+			p = item->next;
+			for( j = 0; j < MBR_ITEM_MAX_N; j++, p = p->next ){
+				if( p == item )
+					break;
 
-			sprintf( ls[k].path, "/item/%ld%c",
-					i, (char)('A' + j) );
-			str_nz_cpy( ls[k].kind, "<Branch>",
-					MENU_KIND_MAX_LEN );
-			ls[k].accel_key = (char)('A' + j);
-			ls[k].short_key[0] = '\0';
-			ls[k].n_msg = N_MSG_NULL;
-			sprintf( ls[k].msg, " %s", p->name );
-			ls[k].call_back = cb_menu_item_sel;
-			ls[k].arg = NULL;
-			ls[k].flg = FLG_NULL;
-			k++;
+				sprintf( ls[k].path, "/item/%ld%c",
+						i, (char)('A' + j) );
+				str_nz_cpy( ls[k].kind, "<Branch>",
+						MENU_KIND_MAX_LEN );
+				ls[k].accel_key = (char)('A' + j);
+				ls[k].short_key[0] = '\0';
+				ls[k].n_msg = N_MSG_NULL;
+				sprintf( ls[k].msg, " %s", p->name );
+				ls[k].call_back = cb_menu_item_sel;
+				ls[k].arg = NULL;
+				ls[k].flg = FLG_NULL;
+				k++;
+			}
 		}
 
 		sprintf( ls[k].path, "/item/%ld%s", i, "equip" );
@@ -1448,7 +1450,11 @@ char	*cb_menu_item_sel( menu_t **pp, menu_t **dflt )
 	g_sel_item = NULL;
 
 	item_idx = node[1] - 'A';
+
 	item_head = get_mbr_item_asgn( pty->mbr[g_sel_mbr_n] );
+	if( item_head == NULL )
+		return STR_MENU_ERR;
+
 	item = item_head->next;
 	for( i = 0; i < MBR_ITEM_MAX_N; i++ ){
 		if( item == item_head )
@@ -1965,6 +1971,9 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 			equip_kind_t	eq_k;
 			char	*msg;
 
+			if( equip == NULL )
+				break;
+
 			eq_k = ls_equip_msg[j].kind;
 
 			msg = MSG( ls_equip_msg[j].n_msg );
@@ -2122,6 +2131,8 @@ char	*menu_equip_wear_sel( menu_t **pp, menu_t **dflt )
 	k++;
 
 	item = get_mbr_item_asgn( pty->mbr[g_sel_mbr_n] );
+	if( item == NULL )
+		return STR_MENU_ERR;
 	p = item->next;
 	for( i = 0; i < MBR_ITEM_MAX_N; i++, p = p->next ){
 		if( p == item )
@@ -2724,9 +2735,12 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 		k++;
 
 		item = get_mbr_item_asgn( pty->mbr[i] );
-		p = item->next;
+		if( item == NULL )
+			p = NULL;
+		else
+			p = item->next;
 		j = 0;
-		if( p == item ){
+		if( (p == NULL) || (p == item) ){
 			sprintf( ls[k].path,
 					"/identify item/unknown %c",
 					(char)('A' + i) );
