@@ -15,6 +15,9 @@ request_t	*make_request_exterminate( request_t *req );
 request_t	*make_request_revenge( request_t *req );
 request_t	*make_request_wanted_criminal( request_t *req );
 bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now );
+long	get_request_dun_max_lev_easy( void );
+long	get_request_dun_max_lev_normal( void );
+long	get_request_dun_max_lev( long dun_min_lev, long dun_max_lev );
 void	set_request_dun_lev(
 	request_t *req,
 	long min_lev, long max_lev, long range_lev
@@ -85,9 +88,9 @@ bool_t	chr_contract_request(
 	request_t *req,
 	chr_kind_t kind, n_msg_idx_t n_idx_name, sex_t sex
 );
+void	chk_find_request_chr( chr_t *chr );
 bool_t	finish_request( request_t *req );
 bool_t	dont_finish_request( request_t *req );
-void	chk_find_request_chr( chr_t *chr );
 void	chk_finish_request_chr_dead( chr_t *chr );
 void	chk_finish_request_rare_goods( void );
 bool_t	chk_finish_request_join( request_t *req, mnstr_t *npc );
